api/track/sucks.json
Пред. | Глава 6. Web API | След.

## api/track/sucks.json

Записывает неодобрение пользователем текущей композиции. Для голосования против композиции, звучавшей ранее, её идентификатор можно указать в параметре `id`.

Запросы нужно отправлять методом POST, указав полученный при аутентификации токен. Пример:

    $ curl -X POST -d 'token=baadf00d&track_id=123' http://music.tmradio.net/api/track/sucks.json
    {
      "status": "ok",
      "message": "OK, current weight of track #123 is 1.9333."
    }

Пред. | Наверх | След.
api/track/rocks.json | Начало | api/track/info.json